"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from ._hooks import SDKHooks
from .httpclient import AsyncHttpClient, HttpClient
from .utils import Logger, RetryConfig, remove_suffix
from dataclasses import dataclass
from mixpeek import models
from mixpeek.models import internal
from mixpeek.types import OptionalNullable, UNSET
from pydantic import Field
from typing import Callable, Dict, Optional, Tuple, Union


SERVERS = [
    "https://api.mixpeek.com/",
]
"""Contains the list of servers available to the SDK"""


@dataclass
class SDKConfiguration:
    client: HttpClient
    async_client: AsyncHttpClient
    debug_logger: Logger
    globals: internal.Globals
    security: Optional[Union[models.Security, Callable[[], models.Security]]] = None
    server_url: Optional[str] = ""
    server_idx: Optional[int] = 0
    language: str = "python"
    openapi_doc_version: str = "0.81"
    sdk_version: str = "0.15.1"
    gen_version: str = "2.484.0"
    user_agent: str = "speakeasy-sdk/python 0.15.1 2.484.0 0.81 mixpeek"
    retry_config: OptionalNullable[RetryConfig] = Field(default_factory=lambda: UNSET)
    timeout_ms: Optional[int] = None

    def __post_init__(self):
        self._hooks = SDKHooks()

    def get_server_details(self) -> Tuple[str, Dict[str, str]]:
        if self.server_url is not None and self.server_url:
            return remove_suffix(self.server_url, "/"), {}
        if self.server_idx is None:
            self.server_idx = 0

        return SERVERS[self.server_idx], {}

    def get_hooks(self) -> SDKHooks:
        return self._hooks



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class Permission(str, Enum):
    READ = "read"
    WRITE = "write"
    ADMIN = "admin"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from mixpeek.types import BaseModel
from mixpeek.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class DeleteAPIKeyOrganizationsUsersUserEmailAPIKeysKeyNameDeleteRequestTypedDict(
    TypedDict
):
    user_email: str
    key_name: str


class DeleteAPIKeyOrganizationsUsersUserEmailAPIKeysKeyNameDeleteRequest(BaseModel):
    user_email: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    key_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .modeldetails import ModelDetails, ModelDetailsTypedDict
from .payloadindextype import PayloadIndexType, PayloadIndexTypeTypedDict
from mixpeek.types import BaseModel
from typing import Dict, List
from typing_extensions import TypedDict


class AvailableIndexesResponseTypedDict(TypedDict):
    r"""Response schema for available indexes endpoint"""

    embedding_models: Dict[str, ModelDetailsTypedDict]
    payload_indexes: List[PayloadIndexTypeTypedDict]


class AvailableIndexesResponse(BaseModel):
    r"""Response schema for available indexes endpoint"""

    embedding_models: Dict[str, ModelDetails]

    payload_indexes: List[PayloadIndexType]
